from onlinesimru.api import Api


class GetRent(Api):
    def get(self, country: int = 7, days: int = 1, extension: bool = False):
        return self._get(
            f"/rent/getRentNum",
            {"country": country, "days": days, "extension": extension},
        )["item"]

    def state(self):
        return self._get(f"/rent/getRentState", {"pagination": False})["list"]

    def stateOne(self, tzid: int):
        return self._get(f"/rent/getRentState", {"tzid": tzid, "pagination": False})[
            "list"
        ][0]

    def extend(self, tzid: int, days: int = 1):
        return self._get(f"/rent/extendRentState", {"tzid": tzid, "days": days})["item"]

    def portReload(self, tzid: int):
        return self._get(f"/rent/portReload", {"tzid": tzid})

    def tariffs(self):
        return self._get(f"/rent/tariffsRent", {})

    def tariffsOne(self, country: int = 7):
        return self._get(f"/rent/tariffsRent", {"country": country})

    def close(self, tzid: int):
        return self._get(f"/rent/closeRentNum", {"tzid": tzid})



from typing import List
from onlinesimru.api import Api


class GetForward(Api):
    def get(
        self,
        forward_numbers: List[int] = None,
        service: str = "unlimited_sms",
        region: int = None,
        reject: List[int] = None,
    ):
        return self._get(
            f"/getForward",
            {
                "forward_numbers": forward_numbers,
                "service": service,
                "region": region,
                "reject": reject,
            },
        )["tzid"]

    def state(
        self,
        message_to_code: int = 1,
        orderby: str = "ASC",
        msg_list: bool = True,
        clean: bool = True,
    ):
        return self._get(
            f"/getState",
            {
                "message_to_code": message_to_code,
                "orderby": orderby,
                "msg_list": msg_list,
                "clean": clean,
                "type": "forward",
            },
        )

    def stateOne(
        self,
        tzid: int,
        message_to_code: int = 1,
        orderby: str = "ASC",
        msg_list: bool = True,
        clean: bool = True,
    ):
        return self._get(
            f"/getState",
            {
                "tzid": tzid,
                "message_to_code": message_to_code,
                "orderby": orderby,
                "msg_list": msg_list,
                "clean": clean,
                "type": "forward",
            },
        )

    def close(self, tzid: int):
        return self._get(f"/setOperationOk", {"tzid": tzid})

    def repeat(self, service: int, number: int):
        return self._get(f"/getNumRepeat", {"service": service, "number": number})[
            "tzid"
        ]

    def tariffs(self):
        return self._get(f"/getNumbersStats", {"country": "all"})

    def tariffsOne(self, country: int = 7):
        return self._get(f"/getNumbersStats", {"country": country})

    def service(self):
        return self._get(f"/getService", {})["service"]

    def serviceNumber(self, service: str):
        return self._get(f"/getServiceNumber", {"service": service})["number"]



# -*- coding: utf-8 -*-
from .GetForward import GetForward
from .GetFree import GetFree
from .GetNumbers import GetNumbers
from .GetProxy import GetProxy
from .GetRent import GetRent
from .GetUser import GetUser
from .Driver import Driver
from ._version import __version__


__author__ = "s00d"
__version__ = __version__
__contact__ = "https://github.com/s00d"



from os import path
from setuptools import setup
import re

"""
@author: s00d
@contact: https://github.com/s00d
@license Apache License, Version 2.0, see LICENSE file
Copyright (C) 2020
"""


VERSIONFILE="onlinesimru/_version.py"
verstrline = open(VERSIONFILE, "rt").read()
VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
mo = re.search(VSRE, verstrline, re.M)
if mo:
    verstr = mo.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))



def long_description():
    """Build the description from README file """
    this_dir = path.abspath(path.dirname(__file__))
    with open(path.join(this_dir, "README.md")) as f:
        return f.read()


def requirements():
    """Build the requirements list for this project"""
    requirements_list = list()
    with open("requirements.txt") as pc_requirements:
        for install in pc_requirements:
            requirements_list.append(install.strip())
    return requirements_list


setup(
    name="onlinesimru",
    version=verstr,
    long_description=long_description(),
    long_description_content_type="text/markdown",
    description="Wrapper for automatic reception of SMS-messages by onlinesim.ru",
    author="s00d",
    license="Apache License, Version 2.0, see LICENSE file",
    keywords="sms, revice, onlinesim-ru, autoreg",
    author_email="suppport@onlinesim.ru",
    url="https://github.com/s00d/onlinesim-python-api",
    download_url="https://github.com/s00d/onlinesim-python-api/archive/master.zip",
    packages=["onlinesimru"],
    install_requires=requirements(),
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Environment :: Console",
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],
)
